Learn R Programming

minimapR (version 0.0.1.3)

minimap2_installation: minimap2_installation

Description

This function prints installation instructions specific to the user's operating system.

Usage

minimap2_installation(verbose = TRUE)

Value

This function returns the path of the installed 'minimap2' tool (character).

Arguments

verbose

Logical value to print progress of the installation

Examples

Run this code
if (FALSE) {
minimap2_installation(verbose = FALSE)
}

Run the code above in your browser using DataLab