Learn R Programming

minimapR (version 0.0.1.3)

mm2_install: minimap2_install

Description

Install minimap2 using conda or mamba. Conda or mamba is required for installation.

Usage

mm2_install(verbose = TRUE)

Value

If 'minimap2' is not installed, this function installs it on windows, linux or macOS.

Arguments

verbose

Logical value to print progress of the installation. Default is TRUE. If set to FALSE, it will suppress the output messages during installation.

Examples

Run this code
if (FALSE) {
mm2_install(verbose = TRUE)
}

Run the code above in your browser using DataLab