powered by
This function prints installation instructions specific to the user's operating system.
minimap2_installation(verbose = TRUE)
This function returns the path of the installed 'minimap2' tool (character).
Logical value to print progress of the installation
if (FALSE) { minimap2_installation(verbose = FALSE) }
Run the code above in your browser using DataLab