powered by
Install minimap2 using conda or mamba. Conda or mamba is required for installation.
minimap2
mm2_install(verbose = TRUE)
If 'minimap2' is not installed, this function installs it on windows, linux or macOS.
Logical value to print progress of the installation. Default is TRUE. If set to FALSE, it will suppress the output messages during installation.
TRUE
FALSE
if (FALSE) { mm2_install(verbose = TRUE) }
Run the code above in your browser using DataLab